@@ -80,14 +80,14 @@ function unwrapSpecialTwitterURLs() {
   });
 }
 
-//TODO race condition; fix waiting on https://crbug.com/478183
-chrome.runtime.sendMessage({checkEnabled: true},
-  function (enabled) {
-    if (!enabled) {
-      return;
-    }
-    unwrapSpecialTwitterURLs();
-    unwrapTwitterURLsInTimeline();
-    setInterval(unwrapTwitterURLsInTimeline, 2000);
+// TODO race condition; fix waiting on https://crbug.com/478183
+chrome.runtime.sendMessage({
+  type: "checkEnabled",
+}, function (enabled) {
+  if (!enabled) {
+    return;
   }
-);
+  unwrapSpecialTwitterURLs();
+  unwrapTwitterURLsInTimeline();
+  setInterval(unwrapTwitterURLsInTimeline, 2000);
+});
