@@ -1625,6 +1625,21 @@ var multiDomainFirstPartiesArray = [
 
     "getgo.com",
   ],
+  [
+    "loveholidays.com",
+    "loveholidays.be",
+    "loveholidays.dk",
+    "loveholidays.es",
+    "loveholidays.fi",
+    "loveholidays.fr",
+    "loveholidays.ie",
+    "loveholidays.nl",
+    "loveholidays.no",
+    "loveholidays.co.nz",
+    "loveholidays.pt",
+    "loveholidays.se",
+    "lovevacations.com",
+  ],
   ["macys.com", "macysassets.com"],
   [
     "mafra.cz",
@@ -2773,6 +2788,8 @@ var multiDomainFirstPartiesArray = [
     "tripadvisor.se",
     "tripadvisor.sk",
 
+    "seatguru.com",
+
     "tacdn.com",
     "tamgrt.com",
   ],
@@ -3052,6 +3069,16 @@ var multiDomainFirstPartiesArray = [
     "turner.com",
     "ugdturner.com",
   ],
+  [
+    "weather.com",
+    "wunderground.com",
+
+    "imwx.com",
+    "wfxtriggers.com",
+    "wsi.com",
+    "w-x.co",
+    "wxug.com",
+  ],
   [
     "webmd.com",
 
