@@ -99,7 +99,6 @@ function loadOptions() {
     }
   });
   $("button").button();
-  $(".refreshButton").button("option", "icons", {primary: "ui-icon-refresh"});
   $(".addButton").button("option", "icons", {primary: "ui-icon-plus"});
   $(".removeButton").button("option", "icons", {primary: "ui-icon-minus"});
   $("#cloud-upload").button("option", "icons", {primary: "ui-icon-arrowreturnthick-1-n"});
@@ -122,12 +121,15 @@ function loadOptions() {
     $("#toggle_webrtc_mode").on("click", toggleWebRTCIPProtection);
 
     chrome.privacy.network.webRTCIPHandlingPolicy.get({}, result => {
+      // only enable the checkbox if pb can control webrtc ip leak protection
       if (result.levelOfControl.endsWith("_by_this_extension")) {
         $("#toggle_webrtc_mode").attr("disabled", false);
       }
 
-      $("#toggle_webrtc_mode").prop(
-        "checked", result.value == "disable_non_proxied_udp");
+      // auto check the option box if ip leak is already protected at diff levels, via pb or another extension
+      if (result.value == "default_public_interface_only" || result.value == "disable_non_proxied_udp") {
+        $("#toggle_webrtc_mode").prop("checked", true);
+      }
     });
 
   } else {
@@ -226,6 +228,14 @@ function parseUserDataFile(storageMapsList) {
     return confirm(i18n.getMessage("invalid_json"));
   }
 
+  // validate by checking we have the same keys in the import as in the export
+  if (!_.isEqual(
+    Object.keys(lists).sort(),
+    USER_DATA_EXPORT_KEYS.sort()
+  )) {
+    return confirm(i18n.getMessage("invalid_json"));
+  }
+
   // check for webrtc setting in the imported settings map
   if (lists.settings_map.preventWebRTCIPLeak) {
     // verify that the user hasn't already enabled this option
@@ -236,14 +246,6 @@ function parseUserDataFile(storageMapsList) {
     delete lists.settings_map.preventWebRTCIPLeak;
   }
 
-  // validate by checking we have the same keys in the import as in the export
-  if (!_.isEqual(
-    Object.keys(lists).sort(),
-    USER_DATA_EXPORT_KEYS.sort()
-  )) {
-    return confirm(i18n.getMessage("invalid_json"));
-  }
-
   chrome.runtime.sendMessage({
     type: "mergeUserData",
     data: lists
@@ -377,7 +379,7 @@ function exportUserData() {
     // https://bugzilla.mozilla.org/show_bug.cgi?id=1420419
     if (chrome.runtime.getBrowserInfo) {
       chrome.runtime.getBrowserInfo((info) => {
-        if (info.name == "Firefox") {
+        if (info.name == "Firefox" || info.name == "Waterfox") {
           addBlobWorkAroundForFirefox();
         }
         clickBlobLink();
@@ -549,7 +551,7 @@ function reloadTrackingDomainsTab() {
     $("#tracking-domains-div").hide();
 
     // activate tooltips
-    $('.tooltip').tooltipster(TOOLTIP_CONF);
+    $('.tooltip:not(.tooltipstered)').tooltipster(TOOLTIP_CONF);
 
     return;
   }
@@ -580,7 +582,7 @@ function reloadTrackingDomainsTab() {
   $("#blockedResources")[0].innerHTML = htmlUtils.getTrackerContainerHtml();
 
   // activate tooltips
-  $('.tooltip').tooltipster(TOOLTIP_CONF);
+  $('.tooltip:not(.tooltipstered)').tooltipster(TOOLTIP_CONF);
 
   // Display tracking domains.
   showTrackingDomains(
@@ -686,7 +688,11 @@ function addOrigins(e) {
     var domain = domains.shift();
     var action = getOriginAction(domain);
     if (action) {
-      $(target).append(htmlUtils.getOriginHtml(domain, action, action == constants.DNT));
+      let show_breakage_warning = (
+        action == constants.USER_BLOCK &&
+        OPTIONS_DATA.cookieblocked.hasOwnProperty(domain)
+      );
+      $(target).append(htmlUtils.getOriginHtml(domain, action, show_breakage_warning));
 
       // register the newly-created toggle switch so that user changes are saved
       registerToggleHandlers($(target).find("[data-origin='" + domain + "'] .switch-toggle"));
@@ -708,10 +714,14 @@ function showTrackingDomains(domains) {
   // Create HTML for the initial list of tracking domains.
   var trackingDetails = '';
   for (var i = 0; (i < 50) && (domains.length > 0); i++) {
-    var trackingDomain = domains.shift();
-    var action = getOriginAction(trackingDomain);
+    var domain = domains.shift();
+    var action = getOriginAction(domain);
     if (action) {
-      trackingDetails += htmlUtils.getOriginHtml(trackingDomain, action, action == constants.DNT);
+      let show_breakage_warning = (
+        action == constants.USER_BLOCK &&
+        OPTIONS_DATA.cookieblocked.hasOwnProperty(domain)
+      );
+      trackingDetails += htmlUtils.getOriginHtml(domain, action, show_breakage_warning);
     }
   }
 
@@ -777,16 +787,21 @@ function updateOrigin(event) {
     constants.COOKIEBLOCK,
     constants.ALLOW,
     constants.NO_TRACKING].join(" ")).addClass(action);
-  var $clicker = $elm.parents('.clicker').first();
-  htmlUtils.toggleBlockedStatus($clicker, action);
+
+  let $clicker = $elm.parents('.clicker').first(),
+    origin = $clicker.data('origin'),
+    show_breakage_warning = (
+      action == constants.BLOCK &&
+      OPTIONS_DATA.cookieblocked.hasOwnProperty(origin)
+    );
+
+  htmlUtils.toggleBlockedStatus($clicker, action, show_breakage_warning);
 
   // reinitialize the domain tooltip
-  $clicker.find('.origin').tooltipster('destroy');
-  $clicker.find('.origin').attr(
-    'title',
-    htmlUtils.getActionDescription(action, $clicker.data('origin'))
-  );
-  $clicker.find('.origin').tooltipster(htmlUtils.DOMAIN_TOOLTIP_CONF);
+  $clicker.find('.origin-inner').tooltipster('destroy');
+  $clicker.find('.origin-inner').attr(
+    'title', htmlUtils.getActionDescription(action, origin));
+  $clicker.find('.origin-inner').tooltipster(htmlUtils.DOMAIN_TOOLTIP_CONF);
 }
 
 /**
