@@ -218,6 +218,27 @@ BadgerPen.prototype = {
     dnt_hashes.updateObject(_.invert(hashes));
   },
 
+  /**
+   * Looks up whether an FQDN would get cookieblocked, ignoring user overrides.
+   *
+   * @param {String} fqdn the FQDN we want to look up
+   *
+   * @return {Boolean}
+   */
+  getCookieblockStatus: function (fqdn) {
+    let actionMap = this.getBadgerStorageObject('action_map'),
+      subdomains = utils.explodeSubdomains(fqdn);
+
+    for (let i = 0; i < subdomains.length; i++) {
+      let action = actionMap.getItem(subdomains[i]);
+      if (action && action.heuristicAction == constants.COOKIEBLOCK) {
+        return true;
+      }
+    }
+
+    return false;
+  },
+
   /**
    * Find the best action to take for an FQDN, assuming it is third party and
    * Privacy Badger is enabled. Traverse the action list for the FQDN and each
@@ -400,6 +421,34 @@ BadgerPen.prototype = {
       log("Removing %s from action_map", domain);
       actionMap.deleteItem(domain);
     }
+  },
+
+  /**
+   * Removes a base domain and its subdomains from snitch and action maps.
+   * Preserves action map entries with user overrides.
+   *
+   * @param {String} base_domain
+   */
+  forget: function (base_domain) {
+    let self = this,
+      dot_base = '.' + base_domain,
+      actionMap = self.getBadgerStorageObject('action_map'),
+      actions = actionMap.getItemClones(),
+      snitchMap = self.getBadgerStorageObject('snitch_map');
+
+    if (snitchMap.getItem(base_domain)) {
+      log("Removing %s from snitch_map", base_domain);
+      badger.storage.getBadgerStorageObject("snitch_map").deleteItem(base_domain);
+    }
+
+    for (let domain in actions) {
+      if (domain == base_domain || domain.endsWith(dot_base)) {
+        if (actions[domain].userAction == "") {
+          log("Removing %s from action_map", domain);
+          actionMap.deleteItem(domain);
+        }
+      }
+    }
   }
 };
 
