@@ -8,7 +8,6 @@ import pbtest
 from functools import partial
 
 from pbtest import retry_until
-from window_utils import switch_to_window_with_url
 
 
 class FingerprintingTest(pbtest.PBSeleniumTest):
@@ -16,9 +15,10 @@ class FingerprintingTest(pbtest.PBSeleniumTest):
 
     def detected_fingerprinting(self, domain):
         return self.js("""let tracker_origin = window.getBaseDomain("{}");
+let tabData = chrome.extension.getBackgroundPage().badger.tabData;
 return (
-  Object.keys(badger.tabData).some(tab_id => {{
-    let fpData = badger.tabData[tab_id].fpData;
+  Object.keys(tabData).some(tab_id => {{
+    let fpData = tabData[tab_id].fpData;
     return fpData &&
       fpData.hasOwnProperty(tracker_origin) &&
       fpData[tracker_origin].canvas &&
@@ -29,7 +29,7 @@ return (
     def detected_tracking(self, domain, page_url):
         return self.js("""let tracker_origin = window.getBaseDomain("{}"),
   site_origin = window.getBaseDomain((new URI("{}")).host),
-  map = badger.storage.snitch_map.getItemClones();
+  map = chrome.extension.getBackgroundPage().badger.storage.snitch_map.getItemClones();
 
 return (
   map.hasOwnProperty(tracker_origin) &&
@@ -39,35 +39,34 @@ return (
     # TODO can fail because our content script runs too late: https://crbug.com/478183
     @pbtest.repeat_if_failed(3)
     def test_canvas_fingerprinting_detection(self):
-        PAGE_URL = (
-            "https://gitcdn.link/cdn/ghostwords/"
-            "ff6347b93ec126d4f73a9ddfd8b09919/raw/6b215b3f052115d36831ecfca758081ca7da7e37/"
-            "privacy_badger_fingerprint_test_fixture.html"
+        FIXTURE_URL = (
+            "https://efforg.github.io/privacybadger-test-fixtures/html/"
+            "fingerprinting.html"
         )
         FINGERPRINTING_DOMAIN = "cdn.jsdelivr.net"
 
-        # open Badger's background page
-        self.load_url(self.bg_url)
-
-        # need to keep Badger's background page open for tabData to persist
-        # so, open and switch to a new window
-        self.open_window()
+        # clear pre-trained/seed tracker data
+        self.load_url(self.options_url)
+        self.js("chrome.extension.getBackgroundPage().badger.storage.clearTrackerData();")
 
         # visit the page
-        self.load_url(PAGE_URL)
+        self.load_url(FIXTURE_URL)
 
-        # switch back to Badger's background page
-        switch_to_window_with_url(self.driver, self.bg_url)
+        # now open a new window (to avoid clearing badger.tabData)
+        # and verify results
+        self.open_window()
 
         # check that we detected the fingerprinting domain as a tracker
+        self.load_url(self.options_url)
+        # TODO unnecessary retrying?
         self.assertTrue(
-            retry_until(partial(self.detected_tracking, FINGERPRINTING_DOMAIN, PAGE_URL)),
+            retry_until(partial(self.detected_tracking, FINGERPRINTING_DOMAIN, FIXTURE_URL)),
             "Canvas fingerprinting resource was detected as a tracker.")
 
         # check that we detected canvas fingerprinting
         self.assertTrue(
             self.detected_fingerprinting(FINGERPRINTING_DOMAIN),
-            "Canvas fingerprinting resources was detected as a fingerprinter."
+            "Canvas fingerprinting resource was detected as a fingerprinter."
         )
 
 
