@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 
-import json
 import time
 import unittest
 
@@ -45,42 +44,43 @@ class PopupTest(pbtest.PBSeleniumTest):
 
             self.fail("Timed out waiting for %s to start loading" % url)
 
-    def open_popup(self, close_overlay=True, origins=None):
+    def open_popup(self, show_nag=False, origins=None):
         """Open popup and optionally close overlay."""
 
-        # TODO Hack: Open a new window to work around popup.js thinking the
-        # active page is firstRun.html when popup.js checks whether the overlay
-        # should be shown. Opening a new window should make the popup think
-        # it's on popup.html instead. This doesn't change what happens in
-        # Chrome where popup.js will keep thinking it is on popup.html.
-        self.open_window()
-
-        self.load_url(self.popup_url)
-        self.wait_for_script("return window.POPUP_INITIALIZED")
+        DUMMY_PAGE_URL = "https://efforg.github.io/privacybadger-test-fixtures/"
 
         # hack to get tabData populated for the popup's tab
         # to get the popup shown for regular pages
         # as opposed to special (no-tabData) browser pages
-        # TODO instead use a proper popup-opening function to open the popup
-        # for some test page like https://www.eff.org/files/badgertest.txt;
-        # for example, see https://github.com/EFForg/privacybadger/issues/1634
-        js = """getTab(function (tab) {
-  chrome.runtime.sendMessage({
-    type: "getPopupData",
-    tabId: tab.id,
-    tabUrl: tab.url
-  }, (response) => {
-    response.noTabData = false;
-    response.origins = %s;
-    setPopupData(response);
-    refreshPopup();
-    window.DONE_REFRESHING = true;
-  });
-});"""
-        js = js % (
-            json.dumps(origins) if origins else "{}",
+        self.open_window()
+        self.load_url(DUMMY_PAGE_URL)
+
+        self.open_window()
+        self.load_url(self.popup_url)
+        self.wait_for_script("return window.POPUP_INITIALIZED")
+
+        # override tab ID (to get regular page popup instead of
+        # special browser page popup),
+        # optionally set the domains the popup should report,
+        # optionally ask for the new user welcome page reminder
+        popup_js = (
+            "(function (origins, show_nag, DUMMY_PAGE_URL) {"
+            "chrome.tabs.query({ url: DUMMY_PAGE_URL }, (tabs) => {"
+            "  chrome.runtime.sendMessage({"
+            "    type: 'getPopupData',"
+            "    tabId: tabs[0].id"
+            "  }, (response) => {"
+            "    response.seenComic = !show_nag;"
+            "    response.origins = origins;"
+            "    setPopupData(response);"
+            "    refreshPopup();"
+            "    showNagMaybe();"
+            "    window.DONE_REFRESHING = true;"
+            "  });"
+            "});"
+            "}(arguments[0], arguments[1], arguments[2]));"
         )
-        self.js(js)
+        self.js(popup_js, origins if origins else {}, show_nag, DUMMY_PAGE_URL)
         # wait until the async getTab function is done
         self.wait_for_script(
             "return typeof window.DONE_REFRESHING != 'undefined'",
@@ -91,19 +91,6 @@ class PopupTest(pbtest.PBSeleniumTest):
         # wait for any sliders to finish rendering
         self.wait_for_script("return window.SLIDERS_DONE")
 
-        if close_overlay:
-            # Click 'X' element to close overlay.
-            close_element = self.driver.find_element_by_id("fittslaw")
-            close_element.click()
-
-            # Element will fade out so wait for it to disappear.
-            try:
-                WebDriverWait(self.driver, 5).until(
-                    expected_conditions.invisibility_of_element_located(
-                        (By.ID, "fittslaw")))
-            except TimeoutException:
-                self.fail("Unable to close popup overlay")
-
     def get_enable_button(self):
         """Get enable button on popup."""
         return self.driver.find_element_by_id("activate_site_btn")
@@ -114,7 +101,7 @@ class PopupTest(pbtest.PBSeleniumTest):
 
     def test_overlay(self):
         """Ensure overlay links to first run comic."""
-        self.open_popup(close_overlay=False)
+        self.open_popup(show_nag=True)
 
         self.driver.find_element_by_id("firstRun").click()
 
@@ -233,7 +220,7 @@ class PopupTest(pbtest.PBSeleniumTest):
             "The domain should be blocked on options page.")
 
         # test toggling some more
-        self.open_popup(close_overlay=False, origins={DOMAIN:"user_block"})
+        self.open_popup(origins={DOMAIN:"user_block"})
 
         self.assertTrue(
             self.driver.find_element_by_id("block-" + DOMAIN_ID).is_selected(),
@@ -315,7 +302,7 @@ class PopupTest(pbtest.PBSeleniumTest):
 
         # get back to a valid window handle as the window just got closed
         self.driver.switch_to.window(self.driver.window_handles[0])
-        self.open_popup(close_overlay=False)
+        self.open_popup()
 
         # Check that popup state changed after disabling.
         disable_button = self.get_disable_button()
@@ -328,7 +315,7 @@ class PopupTest(pbtest.PBSeleniumTest):
         enable_button.click()
 
         self.driver.switch_to.window(self.driver.window_handles[0])
-        self.open_popup(close_overlay=False)
+        self.open_popup()
 
         # Check that popup state changed after re-enabling.
         disable_button = self.get_disable_button()
