@@ -28,9 +28,8 @@ class SupercookieTest(pbtest.PBSeleniumTest):
     @pbtest.repeat_if_failed(5)
     def test_async_tracking_misattribution_bug(self):
         self.load_url(
-            "https://gitcdn.link/cdn/ghostwords/"
-            "d3685dc39f7e67dddf1edf2614beb6fc/raw/f52060b329dfeb4e264fcd21c48206cff98786f6/"
-            "privacy_badger_async_bug_test_fixture.html"
+            "https://efforg.github.io/privacybadger-test-fixtures/html/"
+            "async_localstorage_attribution_bug.html"
         )
 
         # the above HTML page reloads itself furiously to trigger our bug
@@ -42,7 +41,7 @@ class SupercookieTest(pbtest.PBSeleniumTest):
         # an iframe from gistcdn.githack.com that writes to localStorage
         self.assertEqual(
             pbtest.retry_until(partial(self.get_snitch_map_for, "githack.com")),
-            ["gitcdn.link"],
+            ["efforg.github.io"],
             msg="IFrame sets localStorage but was not flagged as a tracker.")
 
         # and an image from raw.githubusercontent.com that doesn't do any tracking
@@ -51,10 +50,11 @@ class SupercookieTest(pbtest.PBSeleniumTest):
 
 
     def test_should_detect_ls_of_third_party_frame(self):
+        self.assertFalse(self.get_snitch_map_for("githack.com"))
+
         self.load_url(
-            "https://gitcdn.link/cdn/gunesacar/"
-            "24d81a5c964cb563614162c264be32f0/raw/8fa10f97b87343dfb62ae9b98b753c73a995157e/"
-            "frame_ls.html"
+            "https://efforg.github.io/privacybadger-test-fixtures/html/"
+            "localstorage.html"
         )
 
         # TODO We get some intermittent failures for this test.
@@ -65,14 +65,14 @@ class SupercookieTest(pbtest.PBSeleniumTest):
 
         self.assertEqual(
             pbtest.retry_until(partial(self.get_snitch_map_for, "githack.com"), times=3),
-            ["gitcdn.link"]
+            ["efforg.github.io"]
         )
 
     def test_should_not_detect_low_entropy_ls_of_third_party_frame(self):
+        self.assertFalse(self.get_snitch_map_for("githack.com"))
         self.load_url(
-            "https://gitcdn.link/cdn/gunesacar/"
-            "6f0c39fb728a218ccd91215bfefbd4e0/raw/f438eb4e5ce10dc8623a8834b1298fd4a846c6fa/"
-            "low_entropy_localstorage_from_third_party_script.html"
+            "https://efforg.github.io/privacybadger-test-fixtures/html/"
+            "localstorage_low_entropy.html"
         )
         self.driver.refresh()
         self.assertFalse(self.get_snitch_map_for("githack.com"))
@@ -89,12 +89,11 @@ class SupercookieTest(pbtest.PBSeleniumTest):
     def test_should_not_detect_ls_of_third_party_script(self):
         # a third-party script included by the top page (not a 3rd party frame)
         self.load_url(
-            "https://gitcdn.link/cdn/gunesacar/"
-            "b366e3b03231dbee9709fe0a614faf10/raw/48e02456aa257e272092b398772a712391cf8b11/"
+            "https://efforg.github.io/privacybadger-test-fixtures/html/"
             "localstorage_from_third_party_script.html"
         )
         self.driver.refresh()
-        self.assertFalse(self.get_snitch_map_for("gitcdn.link")) # page URL
+        self.assertFalse(self.get_snitch_map_for("efforg.github.io")) # page URL
         self.assertFalse(self.get_snitch_map_for("githack.com")) # script URL
 
 
